==> paraview_4.1.0+dfsg+1.orig.tar.xz: ParaView-v4.1.0/Qt/Widgets/pqColorDialogEventTranslator.h <==
/*=========================================================================

   Program: ParaView
   Module:  pqColorDialogEventTranslator.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef __pqColorDialogEventTranslator_h
#define __pqColorDialogEventTranslator_h

#include "pqWidgetEventTranslator.h"
#include "pqWidgetsModule.h" // needed for EXPORT macro.
#include <QColor>

/// pqColorDialogEventTranslator translates events on QColorDialog
/// that they can be recorded in tests in a platform independent
/// way.
class PQWIDGETS_EXPORT pqColorDialogEventTranslator :
  public pqWidgetEventTranslator
{
  Q_OBJECT
  typedef pqWidgetEventTranslator Superclass;
public:
  pqColorDialogEventTranslator(QObject* parent=0);
  ~pqColorDialogEventTranslator();

  /// Overridden to handle events on QColorDialog.
  virtual bool translateEvent(QObject* Object, QEvent* Event, bool& Error);

private slots:
  void onColorChosen(const QColor&);
  void onFinished(int);

private:
  pqColorDialogEventTranslator(const pqColorDialogEventTranslator&); // Not implemented.
  void operator=(const pqColorDialogEventTranslator&); // Not implemented.
};

#endif

==> paraview_5.1.2+dfsg1.orig.tar.xz: ParaView-v5.1.2/Qt/Widgets/pqColorDialogEventTranslator.h <==
/*=========================================================================

   Program: ParaView
   Module:  pqColorDialogEventTranslator.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef pqColorDialogEventTranslator_h
#define pqColorDialogEventTranslator_h

#include "pqWidgetEventTranslator.h"
#include "pqWidgetsModule.h" // needed for EXPORT macro.
#include <QColor>

/// pqColorDialogEventTranslator translates events on QColorDialog
/// that they can be recorded in tests in a platform independent
/// way.
class PQWIDGETS_EXPORT pqColorDialogEventTranslator :
  public pqWidgetEventTranslator
{
  Q_OBJECT
  typedef pqWidgetEventTranslator Superclass;
public:
  pqColorDialogEventTranslator(QObject* parent=0);
  ~pqColorDialogEventTranslator();

  /// Overridden to handle events on QColorDialog.
  using Superclass::translateEvent;
  virtual bool translateEvent(QObject* Object, QEvent* Event, bool& Error);

private slots:
  void onColorChosen(const QColor&);
  void onFinished(int);

private:
  pqColorDialogEventTranslator(const pqColorDialogEventTranslator&); // Not implemented.
  void operator=(const pqColorDialogEventTranslator&); // Not implemented.
};

#endif
